aboutsummaryrefslogtreecommitdiff
path: root/video/codecs/cinepak.cpp
diff options
context:
space:
mode:
authorEugene Sandulenko2011-01-23 19:08:09 +0000
committerEugene Sandulenko2011-01-23 19:08:09 +0000
commitcaa6684752a310e916b179125a4125a8b3be36f0 (patch)
treedc364d58619b297194bc5d0673b694c34fb51b6c /video/codecs/cinepak.cpp
parent3d15871ee2d6a9c0ce4819a6ab5925638bafa8b9 (diff)
downloadscummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.gz
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.bz2
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.zip
VIDEO: Move video classes to Video:: namespace
svn-id: r55479
Diffstat (limited to 'video/codecs/cinepak.cpp')
-rw-r--r--video/codecs/cinepak.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/video/codecs/cinepak.cpp b/video/codecs/cinepak.cpp
index 27be2d05ff..2f5cb73561 100644
--- a/video/codecs/cinepak.cpp
+++ b/video/codecs/cinepak.cpp
@@ -29,7 +29,7 @@
// Code here partially based off of ffmpeg ;)
-namespace Graphics {
+namespace Video {
// Convert a color from YUV to RGB colorspace, Cinepak style.
inline static void CPYUV2RGB(byte y, byte u, byte v, byte &r, byte &g, byte &b) {
@@ -54,7 +54,7 @@ CinepakDecoder::CinepakDecoder(int bitsPerPixel) : Codec() {
_y = 0;
if (bitsPerPixel == 8)
- _pixelFormat = PixelFormat::createFormatCLUT8();
+ _pixelFormat = Graphics::PixelFormat::createFormatCLUT8();
else
_pixelFormat = g_system->getScreenFormat();
}
@@ -68,7 +68,7 @@ CinepakDecoder::~CinepakDecoder() {
delete[] _curFrame.strips;
}
-const Surface *CinepakDecoder::decodeImage(Common::SeekableReadStream *stream) {
+const Graphics::Surface *CinepakDecoder::decodeImage(Common::SeekableReadStream *stream) {
_curFrame.flags = stream->readByte();
_curFrame.length = (stream->readByte() << 16) + stream->readUint16BE();
_curFrame.width = stream->readUint16BE();
@@ -88,7 +88,7 @@ const Surface *CinepakDecoder::decodeImage(Common::SeekableReadStream *stream) {
}
if (!_curFrame.surface) {
- _curFrame.surface = new Surface();
+ _curFrame.surface = new Graphics::Surface();
_curFrame.surface->create(_curFrame.width, _curFrame.height, _pixelFormat.bytesPerPixel);
}
@@ -289,4 +289,4 @@ void CinepakDecoder::decodeVectors(Common::SeekableReadStream *stream, uint16 st
}
}
-} // End of namespace Graphics
+} // End of namespace Video